.. highlight:: shell

============
Contributing
============

Contributions are welcome and greatly appreciated! Every little bit helps, and credit will always be given.

You can contribute in many ways!

This repository follows the same contribution guidelines as the `Quantify Core <https://gitlab.com/quantify-os/quantify-core>`_ repository. Please see `these contribution guidelines <https://quantify-quantify-core.readthedocs-hosted.com/en/latest/contributing.html>`_ if you wish to contribute.

Useful links
-------------

- `GitLab Tracker <https://gitlab.com/quantify-os/quantify-scheduler/-/issues>`_
- `GitLab issue board <https://gitlab.com/quantify-os/quantify-scheduler/-/boards>`_
